/*
Copyright The KubeEdge Authors.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/

// Code generated by client-gen. DO NOT EDIT.

package v1alpha1

import (
	"context"
	"time"

	v1alpha1 "github.com/kubeedge/api/apis/apps/v1alpha1"
	scheme "github.com/kubeedge/api/client/clientset/versioned/scheme"
	v1 "k8s.io/apimachinery/pkg/apis/meta/v1"
	types "k8s.io/apimachinery/pkg/types"
	watch "k8s.io/apimachinery/pkg/watch"
	rest "k8s.io/client-go/rest"
)

// EdgeApplicationsGetter has a method to return a EdgeApplicationInterface.
// A group's client should implement this interface.
type EdgeApplicationsGetter interface {
	EdgeApplications(namespace string) EdgeApplicationInterface
}

// EdgeApplicationInterface has methods to work with EdgeApplication resources.
type EdgeApplicationInterface interface {
	Create(ctx context.Context, edgeApplication *v1alpha1.EdgeApplication, opts v1.CreateOptions) (*v1alpha1.EdgeApplication, error)
	Update(ctx context.Context, edgeApplication *v1alpha1.EdgeApplication, opts v1.UpdateOptions) (*v1alpha1.EdgeApplication, error)
	UpdateStatus(ctx context.Context, edgeApplication *v1alpha1.EdgeApplication, opts v1.UpdateOptions) (*v1alpha1.EdgeApplication, error)
	Delete(ctx context.Context, name string, opts v1.DeleteOptions) error
	DeleteCollection(ctx context.Context, opts v1.DeleteOptions, listOpts v1.ListOptions) error
	Get(ctx context.Context, name string, opts v1.GetOptions) (*v1alpha1.EdgeApplication, error)
	List(ctx context.Context, opts v1.ListOptions) (*v1alpha1.EdgeApplicationList, error)
	Watch(ctx context.Context, opts v1.ListOptions) (watch.Interface, error)
	Patch(ctx context.Context, name string, pt types.PatchType, data []byte, opts v1.PatchOptions, subresources ...string) (result *v1alpha1.EdgeApplication, err error)
	EdgeApplicationExpansion
}

// edgeApplications implements EdgeApplicationInterface
type edgeApplications struct {
	client rest.Interface
	ns     string
}

// newEdgeApplications returns a EdgeApplications
func newEdgeApplications(c *AppsV1alpha1Client, namespace string) *edgeApplications {
	return &edgeApplications{
		client: c.RESTClient(),
		ns:     namespace,
	}
}

// Get takes name of the edgeApplication, and returns the corresponding edgeApplication object, and an error if there is any.
func (c *edgeApplications) Get(ctx context.Context, name string, options v1.GetOptions) (result *v1alpha1.EdgeApplication, err error) {
	result = &v1alpha1.EdgeApplication{}
	err = c.client.Get().
		Namespace(c.ns).
		Resource("edgeapplications").
		Name(name).
		VersionedParams(&options, scheme.ParameterCodec).
		Do(ctx).
		Into(result)
	return
}

// List takes label and field selectors, and returns the list of EdgeApplications that match those selectors.
func (c *edgeApplications) List(ctx context.Context, opts v1.ListOptions) (result *v1alpha1.EdgeApplicationList, err error) {
	var timeout time.Duration
	if opts.TimeoutSeconds != nil {
		timeout = time.Duration(*opts.TimeoutSeconds) * time.Second
	}
	result = &v1alpha1.EdgeApplicationList{}
	err = c.client.Get().
		Namespace(c.ns).
		Resource("edgeapplications").
		VersionedParams(&opts, scheme.ParameterCodec).
		Timeout(timeout).
		Do(ctx).
		Into(result)
	return
}

// Watch returns a watch.Interface that watches the requested edgeApplications.
func (c *edgeApplications) Watch(ctx context.Context, opts v1.ListOptions) (watch.Interface, error) {
	var timeout time.Duration
	if opts.TimeoutSeconds != nil {
		timeout = time.Duration(*opts.TimeoutSeconds) * time.Second
	}
	opts.Watch = true
	return c.client.Get().
		Namespace(c.ns).
		Resource("edgeapplications").
		VersionedParams(&opts, scheme.ParameterCodec).
		Timeout(timeout).
		Watch(ctx)
}

// Create takes the representation of a edgeApplication and creates it.  Returns the server's representation of the edgeApplication, and an error, if there is any.
func (c *edgeApplications) Create(ctx context.Context, edgeApplication *v1alpha1.EdgeApplication, opts v1.CreateOptions) (result *v1alpha1.EdgeApplication, err error) {
	result = &v1alpha1.EdgeApplication{}
	err = c.client.Post().
		Namespace(c.ns).
		Resource("edgeapplications").
		VersionedParams(&opts, scheme.ParameterCodec).
		Body(edgeApplication).
		Do(ctx).
		Into(result)
	return
}

// Update takes the representation of a edgeApplication and updates it. Returns the server's representation of the edgeApplication, and an error, if there is any.
func (c *edgeApplications) Update(ctx context.Context, edgeApplication *v1alpha1.EdgeApplication, opts v1.UpdateOptions) (result *v1alpha1.EdgeApplication, err error) {
	result = &v1alpha1.EdgeApplication{}
	err = c.client.Put().
		Namespace(c.ns).
		Resource("edgeapplications").
		Name(edgeApplication.Name).
		VersionedParams(&opts, scheme.ParameterCodec).
		Body(edgeApplication).
		Do(ctx).
		Into(result)
	return
}

// UpdateStatus was generated because the type contains a Status member.
// Add a +genclient:noStatus comment above the type to avoid generating UpdateStatus().
func (c *edgeApplications) UpdateStatus(ctx context.Context, edgeApplication *v1alpha1.EdgeApplication, opts v1.UpdateOptions) (result *v1alpha1.EdgeApplication, err error) {
	result = &v1alpha1.EdgeApplication{}
	err = c.client.Put().
		Namespace(c.ns).
		Resource("edgeapplications").
		Name(edgeApplication.Name).
		SubResource("status").
		VersionedParams(&opts, scheme.ParameterCodec).
		Body(edgeApplication).
		Do(ctx).
		Into(result)
	return
}

// Delete takes name of the edgeApplication and deletes it. Returns an error if one occurs.
func (c *edgeApplications) Delete(ctx context.Context, name string, opts v1.DeleteOptions) error {
	return c.client.Delete().
		Namespace(c.ns).
		Resource("edgeapplications").
		Name(name).
		Body(&opts).
		Do(ctx).
		Error()
}

// DeleteCollection deletes a collection of objects.
func (c *edgeApplications) DeleteCollection(ctx context.Context, opts v1.DeleteOptions, listOpts v1.ListOptions) error {
	var timeout time.Duration
	if listOpts.TimeoutSeconds != nil {
		timeout = time.Duration(*listOpts.TimeoutSeconds) * time.Second
	}
	return c.client.Delete().
		Namespace(c.ns).
		Resource("edgeapplications").
		VersionedParams(&listOpts, scheme.ParameterCodec).
		Timeout(timeout).
		Body(&opts).
		Do(ctx).
		Error()
}

// Patch applies the patch and returns the patched edgeApplication.
func (c *edgeApplications) Patch(ctx context.Context, name string, pt types.PatchType, data []byte, opts v1.PatchOptions, subresources ...string) (result *v1alpha1.EdgeApplication, err error) {
	result = &v1alpha1.EdgeApplication{}
	err = c.client.Patch(pt).
		Namespace(c.ns).
		Resource("edgeapplications").
		Name(name).
		SubResource(subresources...).
		VersionedParams(&opts, scheme.ParameterCodec).
		Body(data).
		Do(ctx).
		Into(result)
	return
}
