/*
Copyright The KubeEdge Authors.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/

// Code generated by client-gen. DO NOT EDIT.

package v1alpha1

import (
	"context"
	"time"

	v1alpha1 "github.com/kubeedge/api/apis/reliablesyncs/v1alpha1"
	scheme "github.com/kubeedge/api/client/clientset/versioned/scheme"
	v1 "k8s.io/apimachinery/pkg/apis/meta/v1"
	types "k8s.io/apimachinery/pkg/types"
	watch "k8s.io/apimachinery/pkg/watch"
	rest "k8s.io/client-go/rest"
)

// ClusterObjectSyncsGetter has a method to return a ClusterObjectSyncInterface.
// A group's client should implement this interface.
type ClusterObjectSyncsGetter interface {
	ClusterObjectSyncs() ClusterObjectSyncInterface
}

// ClusterObjectSyncInterface has methods to work with ClusterObjectSync resources.
type ClusterObjectSyncInterface interface {
	Create(ctx context.Context, clusterObjectSync *v1alpha1.ClusterObjectSync, opts v1.CreateOptions) (*v1alpha1.ClusterObjectSync, error)
	Update(ctx context.Context, clusterObjectSync *v1alpha1.ClusterObjectSync, opts v1.UpdateOptions) (*v1alpha1.ClusterObjectSync, error)
	UpdateStatus(ctx context.Context, clusterObjectSync *v1alpha1.ClusterObjectSync, opts v1.UpdateOptions) (*v1alpha1.ClusterObjectSync, error)
	Delete(ctx context.Context, name string, opts v1.DeleteOptions) error
	DeleteCollection(ctx context.Context, opts v1.DeleteOptions, listOpts v1.ListOptions) error
	Get(ctx context.Context, name string, opts v1.GetOptions) (*v1alpha1.ClusterObjectSync, error)
	List(ctx context.Context, opts v1.ListOptions) (*v1alpha1.ClusterObjectSyncList, error)
	Watch(ctx context.Context, opts v1.ListOptions) (watch.Interface, error)
	Patch(ctx context.Context, name string, pt types.PatchType, data []byte, opts v1.PatchOptions, subresources ...string) (result *v1alpha1.ClusterObjectSync, err error)
	ClusterObjectSyncExpansion
}

// clusterObjectSyncs implements ClusterObjectSyncInterface
type clusterObjectSyncs struct {
	client rest.Interface
}

// newClusterObjectSyncs returns a ClusterObjectSyncs
func newClusterObjectSyncs(c *ReliablesyncsV1alpha1Client) *clusterObjectSyncs {
	return &clusterObjectSyncs{
		client: c.RESTClient(),
	}
}

// Get takes name of the clusterObjectSync, and returns the corresponding clusterObjectSync object, and an error if there is any.
func (c *clusterObjectSyncs) Get(ctx context.Context, name string, options v1.GetOptions) (result *v1alpha1.ClusterObjectSync, err error) {
	result = &v1alpha1.ClusterObjectSync{}
	err = c.client.Get().
		Resource("clusterobjectsyncs").
		Name(name).
		VersionedParams(&options, scheme.ParameterCodec).
		Do(ctx).
		Into(result)
	return
}

// List takes label and field selectors, and returns the list of ClusterObjectSyncs that match those selectors.
func (c *clusterObjectSyncs) List(ctx context.Context, opts v1.ListOptions) (result *v1alpha1.ClusterObjectSyncList, err error) {
	var timeout time.Duration
	if opts.TimeoutSeconds != nil {
		timeout = time.Duration(*opts.TimeoutSeconds) * time.Second
	}
	result = &v1alpha1.ClusterObjectSyncList{}
	err = c.client.Get().
		Resource("clusterobjectsyncs").
		VersionedParams(&opts, scheme.ParameterCodec).
		Timeout(timeout).
		Do(ctx).
		Into(result)
	return
}

// Watch returns a watch.Interface that watches the requested clusterObjectSyncs.
func (c *clusterObjectSyncs) Watch(ctx context.Context, opts v1.ListOptions) (watch.Interface, error) {
	var timeout time.Duration
	if opts.TimeoutSeconds != nil {
		timeout = time.Duration(*opts.TimeoutSeconds) * time.Second
	}
	opts.Watch = true
	return c.client.Get().
		Resource("clusterobjectsyncs").
		VersionedParams(&opts, scheme.ParameterCodec).
		Timeout(timeout).
		Watch(ctx)
}

// Create takes the representation of a clusterObjectSync and creates it.  Returns the server's representation of the clusterObjectSync, and an error, if there is any.
func (c *clusterObjectSyncs) Create(ctx context.Context, clusterObjectSync *v1alpha1.ClusterObjectSync, opts v1.CreateOptions) (result *v1alpha1.ClusterObjectSync, err error) {
	result = &v1alpha1.ClusterObjectSync{}
	err = c.client.Post().
		Resource("clusterobjectsyncs").
		VersionedParams(&opts, scheme.ParameterCodec).
		Body(clusterObjectSync).
		Do(ctx).
		Into(result)
	return
}

// Update takes the representation of a clusterObjectSync and updates it. Returns the server's representation of the clusterObjectSync, and an error, if there is any.
func (c *clusterObjectSyncs) Update(ctx context.Context, clusterObjectSync *v1alpha1.ClusterObjectSync, opts v1.UpdateOptions) (result *v1alpha1.ClusterObjectSync, err error) {
	result = &v1alpha1.ClusterObjectSync{}
	err = c.client.Put().
		Resource("clusterobjectsyncs").
		Name(clusterObjectSync.Name).
		VersionedParams(&opts, scheme.ParameterCodec).
		Body(clusterObjectSync).
		Do(ctx).
		Into(result)
	return
}

// UpdateStatus was generated because the type contains a Status member.
// Add a +genclient:noStatus comment above the type to avoid generating UpdateStatus().
func (c *clusterObjectSyncs) UpdateStatus(ctx context.Context, clusterObjectSync *v1alpha1.ClusterObjectSync, opts v1.UpdateOptions) (result *v1alpha1.ClusterObjectSync, err error) {
	result = &v1alpha1.ClusterObjectSync{}
	err = c.client.Put().
		Resource("clusterobjectsyncs").
		Name(clusterObjectSync.Name).
		SubResource("status").
		VersionedParams(&opts, scheme.ParameterCodec).
		Body(clusterObjectSync).
		Do(ctx).
		Into(result)
	return
}

// Delete takes name of the clusterObjectSync and deletes it. Returns an error if one occurs.
func (c *clusterObjectSyncs) Delete(ctx context.Context, name string, opts v1.DeleteOptions) error {
	return c.client.Delete().
		Resource("clusterobjectsyncs").
		Name(name).
		Body(&opts).
		Do(ctx).
		Error()
}

// DeleteCollection deletes a collection of objects.
func (c *clusterObjectSyncs) DeleteCollection(ctx context.Context, opts v1.DeleteOptions, listOpts v1.ListOptions) error {
	var timeout time.Duration
	if listOpts.TimeoutSeconds != nil {
		timeout = time.Duration(*listOpts.TimeoutSeconds) * time.Second
	}
	return c.client.Delete().
		Resource("clusterobjectsyncs").
		VersionedParams(&listOpts, scheme.ParameterCodec).
		Timeout(timeout).
		Body(&opts).
		Do(ctx).
		Error()
}

// Patch applies the patch and returns the patched clusterObjectSync.
func (c *clusterObjectSyncs) Patch(ctx context.Context, name string, pt types.PatchType, data []byte, opts v1.PatchOptions, subresources ...string) (result *v1alpha1.ClusterObjectSync, err error) {
	result = &v1alpha1.ClusterObjectSync{}
	err = c.client.Patch(pt).
		Resource("clusterobjectsyncs").
		Name(name).
		SubResource(subresources...).
		VersionedParams(&opts, scheme.ParameterCodec).
		Body(data).
		Do(ctx).
		Into(result)
	return
}
